import { Base64 } from "js-base64";
import type { RespResult } from "./core/interface";
import request from "./core/request";
import { loginProxy } from "./core/utils";

/**
 * 获取token
 * @param
 * @returns
 */
export function getToken(params: { username: string; password: string }) {
  return request.post<RespResult<API.UserInfo>>(
    loginProxy + "/auth/oauth2/token",
    {
      /** 去掉前缀 */
      prefix: "",
      requestType: "form",
      headers: {
        Authorization: `Basic ${Base64.encode("cgtf:cgtf")}`,
      },
      data: {
        ...params,
        grant_type: "password",
        scope: "server",
      },
    }
  );
}

/**
 * 获取token
 * @param
 * @returns
 */
export function getUserToken(params: { username: string; password: string }) {
  return request.post<RespResult<API.UserInfo>>(
    loginProxy + "/auth/oauth2/token",
    {
      /** 去掉前缀 */
      prefix: "",
      requestType: "form",
      headers: {
        Authorization: `Basic ${Base64.encode("cgtf:cgtf")}`,
        "CLIENT-TOC": "Y",
      },
      data: {
        ...params,
        grant_type: "password",
        scope: "server",
      },
    }
  );
}

export function getUserProfileInfo() {
  return request.get<RespResult<{ appUser: API.UserInfo }>>(
    loginProxy + "/app/app-user/info",
    {
      prefix: "",
      headers: {
        "CLIENT-TOC": "Y",
      },
    }
  );
}

/** 获取用户基本信息 */
export function getStaffInfo() {
  return request.get<RespResult<API.UserInfo>>(
    loginProxy + "/admin/login/user/simple-info",
    {
      prefix: "",
    }
  );
}

/**
 * @description 用户登录IP监测
 */
export function loginIpCheck(clientIp:string) {
  return request.get<RespResult<any>>("/smzsUserInfo/checkLoginIp?clientIp=" + clientIp, {
    prefix: loginProxy + "/violating-subject",
  });
}
